/*
 * EventDemo.java
 */
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class EventDemo extends JFrame implements ActionListener,
  MouseListener, MouseMotionListener {

	JButton	b;
	Board	p;
	Color	color;

  public EventDemo()
  {
    super( "Paint Board" );

    // add components
    Container cp = getContentPane();
    cp.add( (p = new Board()), BorderLayout.CENTER );
    cp.add( (b = new JButton("Change Color")), BorderLayout.SOUTH );

    p.addMouseListener( this );
    p.addMouseMotionListener( this );
    b.addActionListener( this );

    // set default draw color to be red
    color = Color.red;

    setSize( 400, 400 );
    setLocationRelativeTo( null );
    setDefaultCloseOperation( EXIT_ON_CLOSE );
  }

  // action listener

  public void actionPerformed( ActionEvent e )
  {
    Color c = JColorChooser.showDialog( this, "Choose Color", color );
    if( c != null ) color = c;
    repaint();
  }

  // mouse listener

  public void mouseClicked( MouseEvent e )
  {
    System.out.println( "mouse clicked" );
  }

  public void mouseEntered( MouseEvent e )
  {
    System.out.println( "mouse entered" );
  }

  public void mouseExited( MouseEvent e )
  {
    System.out.println( "mouse exited" );
  }

  public void mousePressed( MouseEvent e )
  {
    System.out.println( "mouse pressed" );
  }

  public void mouseReleased( MouseEvent e )
  {
    System.out.println( "mouse released" );
  }

  // mouse motion listener

  public void mouseDragged( MouseEvent e )
  {
    System.out.println( "mouse dragged" );
  }

  public void mouseMoved( MouseEvent e )
  {
    System.out.println( "mouse moved" );
  }

  // main
  public static void main( String args[] )
  {
    EventDemo p = new EventDemo();
    p.show();
  }

  // A customized panel where we can paint on.
  class Board extends JPanel {

    public void paint( Graphics g )
    {
      super.paint(g);

      int w = getWidth();
      int h = getHeight();

      Color c = g.getColor();
      g.setColor( color );
      g.fillOval( w/4, h/4, w/2, h/2 );
      g.setColor( c );
    }

  } // end of class Board

} // end of class EventDemo

